library easy_route_transition;

import 'package:flutter/material.dart';

enum AnimationType { fadeIn, normal }

class EasyRouteTransition {
  final BuildContext context;
  final Widget child;
  final bool replacement;
  final AnimationType animationType;
  final Duration duration;

  EasyRouteTransition(
      {@required this.context,
      @required this.child,
      this.replacement = false,
      this.animationType = AnimationType.normal,
      this.duration = const Duration(milliseconds: 300)}) {
    switch (this.animationType) {
      case AnimationType.fadeIn:
        this._fadeInTransition();
        break;
      case AnimationType.normal:
        this._normalTransition();
        break;
    }
  }

  void _normalTransition() {
    final route = MaterialPageRoute(builder: (context) => this.child);
    this.replacement ? _pagePush(route) : _pagePushReplacement(route);
  }

  void _fadeInTransition() {
    final route = PageRouteBuilder(
        pageBuilder: (context, animation, secondaryAnimation) => this.child,
        transitionDuration: this.duration,
        transitionsBuilder: (context, animation, secondaryAnimation, child) =>
            FadeTransition(
                child: child,
                opacity: Tween<double>(begin: 0.0, end: 1.0).animate(
                    CurvedAnimation(
                        parent: animation, curve: Curves.easeInOut))));
    this.replacement ? _pagePushReplacement(route) : _pagePush(route);
  }

  void _pagePush(Route route) => Navigator.push(context, route);

  void _pagePushReplacement(Route route) =>
      Navigator.pushReplacement(context, route);
}
